==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/SshConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.SshConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSH configuration for Linux based VMs running on Azure
 * @property publicKeys The list of SSH public keys used to authenticate with linux based VMs.
 */
public data class SshConfigurationArgs(
    public val publicKeys: Output<List<SshPublicKeyArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.SshConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.SshConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.SshConfigurationArgs.builder()
            .publicKeys(
                publicKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SshConfigurationArgs].
 */
@PulumiTagMarker
public class SshConfigurationArgsBuilder internal constructor() {
    private var publicKeys: Output<List<SshPublicKeyArgs>>? = null

    /**
     * @param value The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("xlyeqmxfonajcrin")
    public suspend fun publicKeys(`value`: Output<List<SshPublicKeyArgs>>) {
        this.publicKeys = value
    }

    @JvmName("qcoftykmgeuuwyfb")
    public suspend fun publicKeys(vararg values: Output<SshPublicKeyArgs>) {
        this.publicKeys = Output.all(values.asList())
    }

    /**
     * @param values The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("vthesdgapwsvdmwf")
    public suspend fun publicKeys(values: List<Output<SshPublicKeyArgs>>) {
        this.publicKeys = Output.all(values)
    }

    /**
     * @param value The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("uhglwmupvxuyffre")
    public suspend fun publicKeys(`value`: List<SshPublicKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    /**
     * @param argument The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("lqmjwbnjhlfryafm")
    public suspend fun publicKeys(argument: List<suspend SshPublicKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SshPublicKeyArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("oybyobrlpfflqqjp")
    public suspend fun publicKeys(vararg argument: suspend SshPublicKeyArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SshPublicKeyArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("djisyhdkevjkkiue")
    public suspend fun publicKeys(argument: suspend SshPublicKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SshPublicKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param values The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("ijmwyhvevguukhtv")
    public suspend fun publicKeys(vararg values: SshPublicKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    internal fun build(): SshConfigurationArgs = SshConfigurationArgs(
        publicKeys = publicKeys,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/SshConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.SshConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * SSH configuration for Linux based VMs running on Azure
 * @property publicKeys The list of SSH public keys used to authenticate with linux based VMs.
 */
public data class SshConfigurationArgs(
    public val publicKeys: Output<List<SshPublicKeyArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.SshConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.SshConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.SshConfigurationArgs.builder()
            .publicKeys(
                publicKeys?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SshConfigurationArgs].
 */
@PulumiTagMarker
public class SshConfigurationArgsBuilder internal constructor() {
    private var publicKeys: Output<List<SshPublicKeyArgs>>? = null

    /**
     * @param value The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("eybtjcjwlwxvbgvm")
    public suspend fun publicKeys(`value`: Output<List<SshPublicKeyArgs>>) {
        this.publicKeys = value
    }

    @JvmName("wlmjnadbobgkboba")
    public suspend fun publicKeys(vararg values: Output<SshPublicKeyArgs>) {
        this.publicKeys = Output.all(values.asList())
    }

    /**
     * @param values The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("fpuslrdrcupieujs")
    public suspend fun publicKeys(values: List<Output<SshPublicKeyArgs>>) {
        this.publicKeys = Output.all(values)
    }

    /**
     * @param value The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("ulvtwltlpyalgebo")
    public suspend fun publicKeys(`value`: List<SshPublicKeyArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    /**
     * @param argument The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("stpcigqlhggavjyp")
    public suspend fun publicKeys(argument: List<suspend SshPublicKeyArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SshPublicKeyArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("ahwavxpyxccdilkj")
    public suspend fun publicKeys(vararg argument: suspend SshPublicKeyArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SshPublicKeyArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param argument The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("fubjuqhxupwqkase")
    public suspend fun publicKeys(argument: suspend SshPublicKeyArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SshPublicKeyArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.publicKeys = mapped
    }

    /**
     * @param values The list of SSH public keys used to authenticate with linux based VMs.
     */
    @JvmName("tvbptedmynlatvma")
    public suspend fun publicKeys(vararg values: SshPublicKeyArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicKeys = mapped
    }

    internal fun build(): SshConfigurationArgs = SshConfigurationArgs(
        publicKeys = publicKeys,
    )
}
